@@ -14,12 +14,13 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #ifndef __LIB_GCMD_UTILS_H__
 #define __LIB_GCMD_UTILS_H__
 
+G_BEGIN_DECLS
 
 gchar *
 get_utf8 (const gchar *unknown);
@@ -33,5 +34,6 @@ get_mono_text (const gchar *in);
 gchar *
 get_bold_mono_text (const gchar *in);
 
+G_END_DECLS
 
 #endif //__LIB_GCMD_UTILS_H__
