@@ -14,12 +14,13 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #ifndef __TEST_PLUGIN_H__
 #define __TEST_PLUGIN_H__
 
+G_BEGIN_DECLS
 
 #define TEST_PLUGIN(obj) \
     GTK_CHECK_CAST (obj, test_plugin_get_type (), TestPlugin)
@@ -52,6 +53,6 @@ test_plugin_get_type (void);
 GnomeCmdPlugin *
 test_plugin_new (void);
 
-
+G_END_DECLS
 
 #endif //__TEST_PLUGIN_H__
