@@ -14,12 +14,11 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 #ifndef __GNOME_CMD_CLIST_H__
 #define __GNOME_CMD_CLIST_H__
 
-
 #define GNOME_CMD_CLIST(obj) \
     GTK_CHECK_CAST (obj, gnome_cmd_clist_get_type (), GnomeCmdCList)
 #define GNOME_CMD_CLIST_CLASS(klass) \
@@ -33,7 +32,6 @@ typedef struct _GnomeCmdCListPrivate GnomeCmdCListPrivate;
 typedef struct _GnomeCmdCListClass GnomeCmdCListClass;
 
 
-
 struct _GnomeCmdCList
 {
     GtkCList parent;
@@ -51,28 +49,21 @@ struct _GnomeCmdCListClass
 
 
 
-GtkType
-gnome_cmd_clist_get_type            (void);
+GtkType gnome_cmd_clist_get_type (void);
 
-GtkWidget*
-gnome_cmd_clist_new                 (gint columns);
+GtkWidget *gnome_cmd_clist_new_with_titles (gint columns, gchar **titles);
 
-GtkWidget*
-gnome_cmd_clist_new_with_titles     (gint columns, gchar **titles);
+inline GtkWidget *gnome_cmd_clist_new (gint columns)
+{
+    return gnome_cmd_clist_new_with_titles (columns, NULL);
+}
 
-void
-gnome_cmd_clist_update_style        (GnomeCmdCList *clist);
+void gnome_cmd_clist_update_style        (GnomeCmdCList *clist);
 
-gint
-gnome_cmd_clist_get_voffset         (GnomeCmdCList *clist);
+gint gnome_cmd_clist_get_voffset (GnomeCmdCList *clist);
+void gnome_cmd_clist_set_voffset (GnomeCmdCList *clist, gint voffset);
 
-void
-gnome_cmd_clist_set_voffset         (GnomeCmdCList *clist, gint voffset);
+gint gnome_cmd_clist_get_row (GnomeCmdCList *clist, gint x, gint y);
+void gnome_cmd_clist_set_drag_row (GnomeCmdCList *clist, gint row);
 
-gint
-gnome_cmd_clist_get_row             (GnomeCmdCList *clist, gint x, gint y);
-
-void
-gnome_cmd_clist_set_drag_row        (GnomeCmdCList *clist, gint row);
-
-#endif //__GNOME_CMD_CLIST_H__
+#endif // __GNOME_CMD_CLIST_H__
