@@ -45,50 +45,30 @@ struct _GnomeCmdCmdlineClass
 };
 
 
-GtkWidget*
-gnome_cmd_cmdline_new         (void);
+GtkWidget *gnome_cmd_cmdline_new (void);
 
-GtkType
-gnome_cmd_cmdline_get_type    (void);
+GtkType gnome_cmd_cmdline_get_type (void);
 
-void
-gnome_cmd_cmdline_set_dir     (GnomeCmdCmdline *cmdline, const gchar *cwd);
+GtkWidget *gnome_cmd_cmdline_get_entry (GnomeCmdCmdline *cmdline);
 
-void
-gnome_cmd_cmdline_append_text (GnomeCmdCmdline *cmdline, const gchar *text);
+void gnome_cmd_cmdline_set_dir (GnomeCmdCmdline *cmdline, const gchar *cwd);
 
-void
-gnome_cmd_cmdline_insert_text (GnomeCmdCmdline *cmdline, const gchar *text);
+void gnome_cmd_cmdline_append_text (GnomeCmdCmdline *cmdline, const gchar *text);
+void gnome_cmd_cmdline_insert_text (GnomeCmdCmdline *cmdline, const gchar *text);
+void gnome_cmd_cmdline_set_text (GnomeCmdCmdline *cmdline, const gchar *text);
 
-void
-gnome_cmd_cmdline_set_text    (GnomeCmdCmdline *cmdline, const gchar *text);
+gboolean gnome_cmd_cmdline_is_empty (GnomeCmdCmdline *cmdline);
 
-gboolean
-gnome_cmd_cmdline_is_empty    (GnomeCmdCmdline *cmdline);
+void gnome_cmd_cmdline_exec (GnomeCmdCmdline *cmdline);
 
-void
-gnome_cmd_cmdline_exec        (GnomeCmdCmdline *cmdline);
+void gnome_cmd_cmdline_focus (GnomeCmdCmdline *cmdline);
 
-void
-gnome_cmd_cmdline_focus       (GnomeCmdCmdline *cmdline);
+void gnome_cmd_cmdline_update_style (GnomeCmdCmdline *cmdline);
 
-void
-gnome_cmd_cmdline_update_style (GnomeCmdCmdline *cmdline);
+GList *gnome_cmd_cmdline_get_history (GnomeCmdCmdline *cmdline);
+void gnome_cmd_cmdline_set_history  (GnomeCmdCmdline *cmdline, GList *history);
+void gnome_cmd_cmdline_show_history (GnomeCmdCmdline *cmdline);
 
-void
-gnome_cmd_cmdline_show_history (GnomeCmdCmdline *cmdline);
-
-GList *
-gnome_cmd_cmdline_get_history  (GnomeCmdCmdline *cmdline);
-
-void
-gnome_cmd_cmdline_set_history  (GnomeCmdCmdline *cmdline, GList *history);
-
-GtkWidget *
-gnome_cmd_cmdline_get_entry    (GnomeCmdCmdline *cmdline);
-
-gboolean
-gnome_cmd_cmdline_keypressed   (GnomeCmdCmdline *cmdline,
-                                GdkEventKey *event);
+gboolean gnome_cmd_cmdline_keypressed (GnomeCmdCmdline *cmdline, GdkEventKey *event);
 
 #endif // __GNOME_CMD_CMDLINE_H__
