@@ -33,12 +33,8 @@
 #define __GNOME_CMD_COMBO_H__
 
 #include "imageloader.h"
-#include "gnome-cmd-main-win.h"
-#include "gnome-cmd-file-selector.h"
 #include "gnome-cmd-pixmap.h"
 
-G_BEGIN_DECLS
-
 #define GNOME_CMD_COMBO(obj)            GTK_CHECK_CAST (obj, gnome_cmd_combo_get_type (), GnomeCmdCombo)
 #define GNOME_CMD_COMBO_CLASS(klass)    GTK_CHECK_CLASS_CAST (klass, gnome_cmd_combo_get_type (), GnomeCmdComboClass)
 #define GNOME_CMD_IS_COMBO(obj)         GTK_CHECK_TYPE (obj, gnome_cmd_combo_get_type ())
@@ -47,7 +43,8 @@ typedef struct _GnomeCmdCombo GnomeCmdCombo;
 typedef struct _GnomeCmdComboClass GnomeCmdComboClass;
 
 /* you should access only the entry and list fields directly */
-struct _GnomeCmdCombo {
+struct _GnomeCmdCombo 
+{
     GtkHBox hbox;
     GtkWidget *entry;
     GtkWidget *button;
@@ -73,61 +70,36 @@ struct _GnomeCmdCombo {
     gint text_col;
 };
 
-struct _GnomeCmdComboClass {
+struct _GnomeCmdComboClass 
+{
     GtkHBoxClass parent_class;
 
-    void (* item_selected)     (GnomeCmdCombo *combo,
-                                gpointer data);
+    void (* item_selected)     (GnomeCmdCombo *combo, gpointer data);
     void (* popwin_hidden)     (GnomeCmdCombo *combo);
 };
 
-guint
-gnome_cmd_combo_get_type              (void);
+guint gnome_cmd_combo_get_type (void);
 
-GtkWidget *
-gnome_cmd_combo_new                   (gint num_cols,
-                                       gint text_col,
-                                       gchar **col_titles);
+GtkWidget *gnome_cmd_combo_new (gint num_cols, gint text_col, gchar **col_titles);
 
-void
-gnome_cmd_combo_clear                 (GnomeCmdCombo *combo);
+void gnome_cmd_combo_clear (GnomeCmdCombo *combo);
 
-gint
-gnome_cmd_combo_append                (GnomeCmdCombo *combo,
-                                       gchar         **text,
-                                       gpointer      data);
+gint gnome_cmd_combo_append (GnomeCmdCombo *combo, gchar **text, gpointer data);
 
-gint
-gnome_cmd_combo_insert                (GnomeCmdCombo *combo,
-                                       gchar         **text,
-                                       gpointer      data);
+gint gnome_cmd_combo_insert (GnomeCmdCombo *combo, gchar **text, gpointer data);
 
-void
-gnome_cmd_combo_set_pixmap            (GnomeCmdCombo *combo,
-                                       gint           row,
-                                       gint           col,
-                                       GnomeCmdPixmap *pixmap);
+void gnome_cmd_combo_set_pixmap (GnomeCmdCombo *combo, gint row, gint col, GnomeCmdPixmap *pixmap);
 
-void
-gnome_cmd_combo_popup_list            (GnomeCmdCombo *combo);
+void gnome_cmd_combo_popup_list  (GnomeCmdCombo *combo);
 
-void
-gnome_cmd_combo_select_text           (GnomeCmdCombo *combo,
-                                       const gchar *text);
+void gnome_cmd_combo_select_text (GnomeCmdCombo *combo, const gchar *text);
 
-void
-gnome_cmd_combo_select_data           (GnomeCmdCombo *combo,
-                                       gpointer data);
+void gnome_cmd_combo_select_data (GnomeCmdCombo *combo, gpointer data);
 
-void
-gnome_cmd_combo_update_style          (GnomeCmdCombo *combo);
+void gnome_cmd_combo_update_style (GnomeCmdCombo *combo);
 
-gpointer
-gnome_cmd_combo_get_selected_data     (GnomeCmdCombo *combo);
+gpointer gnome_cmd_combo_get_selected_data (GnomeCmdCombo *combo);
 
-const gchar*
-gnome_cmd_combo_get_selected_text     (GnomeCmdCombo *combo);
-
-G_END_DECLS
+const gchar *gnome_cmd_combo_get_selected_text (GnomeCmdCombo *combo);
 
 #endif // __GNOME_CMD_COMBO_H__
