@@ -39,11 +39,9 @@ typedef void (* DirListDoneFunc) (GnomeCmdDir *dir,
 #include <string>
 
 #include "gnome-cmd-file.h"
-#include "gnome-cmd-con.h"
+#include "gnome-cmd-path.h"
 #include "handle.h"
 
-G_BEGIN_DECLS
-
 typedef enum
 {
     DIR_STATE_EMPTY,
@@ -72,7 +70,6 @@ struct _GnomeCmdDir
     GnomeCmdDirPrivate *priv;
 };
 
-
 struct _GnomeCmdDirClass
 {
     GnomeCmdFileClass parent_class;
@@ -80,10 +77,13 @@ struct _GnomeCmdDirClass
     void (* file_created)       (GnomeCmdDir *dir, GnomeCmdFile *file);
     void (* file_deleted)       (GnomeCmdDir *dir, GnomeCmdFile *file);
     void (* file_changed)       (GnomeCmdDir *dir, GnomeCmdFile *file);
+    void (* file_renamed)       (GnomeCmdDir *dir, GnomeCmdFile *file);
     void (* list_ok)            (GnomeCmdDir *dir, GList *files);
     void (* list_failed)        (GnomeCmdDir *dir, GnomeVFSResult result);
 };
 
+typedef struct _GnomeCmdCon GnomeCmdCon;
+
 GtkType gnome_cmd_dir_get_type (void);
 
 GnomeCmdDir *gnome_cmd_dir_new_from_info (GnomeVFSFileInfo *info, GnomeCmdDir *parent);
@@ -113,12 +113,12 @@ gchar       *gnome_cmd_dir_get_uri_str (GnomeCmdDir *dir);
 GnomeVFSURI *gnome_cmd_dir_get_child_uri (GnomeCmdDir *dir, const gchar *filename);
 gchar       *gnome_cmd_dir_get_child_uri_str (GnomeCmdDir *dir, const gchar *filename);
 
-GnomeVFSURI *gnome_cmd_dir_get_absolute_path_uri (GnomeCmdDir *dir, std::string &filename);
+GnomeVFSURI *gnome_cmd_dir_get_absolute_path_uri (GnomeCmdDir *dir, std::string absolute_filename);
 
-void gnome_cmd_dir_file_created (GnomeCmdDir *dir, const gchar *filename);
-void gnome_cmd_dir_file_deleted (GnomeCmdDir *dir, const gchar *filename);
-void gnome_cmd_dir_file_changed (GnomeCmdDir *dir, const gchar *filename);
-void gnome_cmd_dir_file_renamed (GnomeCmdDir *dir, GnomeCmdFile *finfo);
+void gnome_cmd_dir_file_created (GnomeCmdDir *dir, const gchar *uri_str);
+void gnome_cmd_dir_file_deleted (GnomeCmdDir *dir, const gchar *uri_str);
+void gnome_cmd_dir_file_changed (GnomeCmdDir *dir, const gchar *uri_str);
+void gnome_cmd_dir_file_renamed (GnomeCmdDir *dir, GnomeCmdFile *finfo, const gchar *old_uri_str);
 gboolean gnome_cmd_dir_uses_fam (GnomeCmdDir *dir);
 
 void gnome_cmd_dir_start_monitoring (GnomeCmdDir *dir);
@@ -126,6 +126,4 @@ void gnome_cmd_dir_cancel_monitoring (GnomeCmdDir *dir);
 gboolean gnome_cmd_dir_is_local (GnomeCmdDir *dir);
 void gnome_cmd_dir_set_content_changed (GnomeCmdDir *dir);
 
-G_END_DECLS
-
 #endif // __GNOME_CMD_DIR_H__
