@@ -14,12 +14,12 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
+
 #ifndef __GNOME_CMD_FILE_COLLECTION_H__
 #define __GNOME_CMD_FILE_COLLECTION_H__
 
-
 #include "gnome-cmd-file.h"
 
 #define GNOME_CMD_FILE_COLLECTION(obj) \
@@ -49,40 +49,26 @@ struct _GnomeCmdFileCollectionClass
 };
 
 
-GtkType
-gnome_cmd_file_collection_get_type (void);
+GtkType gnome_cmd_file_collection_get_type (void);
 
-GnomeCmdFileCollection *
-gnome_cmd_file_collection_new (void);
+GnomeCmdFileCollection *gnome_cmd_file_collection_new (void);
 
-void
-gnome_cmd_file_collection_add (GnomeCmdFileCollection *collection,
-                               GnomeCmdFile *file);
+void gnome_cmd_file_collection_add (GnomeCmdFileCollection *collection, GnomeCmdFile *file);
 
-void
-gnome_cmd_file_collection_add_list (GnomeCmdFileCollection *collection,
-                                    GList *files);
+void gnome_cmd_file_collection_add_list (GnomeCmdFileCollection *collection, GList *files);
 
-void
-gnome_cmd_file_collection_remove (GnomeCmdFileCollection *collection,
-                                  GnomeCmdFile *file);
+void gnome_cmd_file_collection_remove (GnomeCmdFileCollection *collection, GnomeCmdFile *file);
 
-void
-gnome_cmd_file_collection_remove_by_uri (GnomeCmdFileCollection *collection,
-                                         const gchar *uri_str);
+void gnome_cmd_file_collection_remove_by_uri (GnomeCmdFileCollection *collection, const gchar *uri_str);
 
-GnomeCmdFile *
-gnome_cmd_file_collection_lookup (GnomeCmdFileCollection *collection,
-                                  const gchar *uri_str);
+GnomeCmdFile *gnome_cmd_file_collection_lookup (GnomeCmdFileCollection *collection, const gchar *uri_str);
 
-gint
-gnome_cmd_file_collection_get_size (GnomeCmdFileCollection *collection);
+gint gnome_cmd_file_collection_get_size (GnomeCmdFileCollection *collection);
 
-void
-gnome_cmd_file_collection_clear (GnomeCmdFileCollection *collection);
+void gnome_cmd_file_collection_clear (GnomeCmdFileCollection *collection);
 
-GList *
-gnome_cmd_file_collection_get_list (GnomeCmdFileCollection *collection);
+GList *gnome_cmd_file_collection_get_list (GnomeCmdFileCollection *collection);
 
+GList *gnome_cmd_file_collection_sort (GnomeCmdFileCollection *collection, GCompareDataFunc compare_func, gpointer user_data);
 
-#endif //__GNOME_CMD_FILE_COLLECTION_H__
+#endif // __GNOME_CMD_FILE_COLLECTION_H__
