@@ -20,9 +20,6 @@
 #ifndef __GNOME_CMD_FILE_H__
 #define __GNOME_CMD_FILE_H__
 
-#include <config.h>
-
-
 #define GNOME_CMD_FILE(obj) \
     GTK_CHECK_CAST (obj, gnome_cmd_file_get_type (), GnomeCmdFile)
 #define GNOME_CMD_FILE_CLASS(klass) \
@@ -34,35 +31,17 @@
 typedef struct _GnomeCmdFile        GnomeCmdFile;
 typedef struct _GnomeCmdFileClass   GnomeCmdFileClass;
 typedef struct _GnomeCmdFilePrivate GnomeCmdFilePrivate;
-typedef struct _GnomeCmdFileMetadata GnomeCmdFileMetadata;
 
-struct _GnomeCmdFileMetadata
-{
-    gboolean accessed;
-    gpointer metadata;
-};
+class GnomeCmdFileMetadata;
 
 struct _GnomeCmdFile
 {
     GnomeCmdFileInfo parent;
 
     GnomeVFSFileInfo *info;
+    gchar *collate_key;                 // necessary for proper sorting of UTF-8 encoded file names
     GnomeCmdFilePrivate *priv;
-#ifdef HAVE_EXIF
-    GnomeCmdFileMetadata exif;
-#endif
-#ifdef HAVE_IPTC
-    GnomeCmdFileMetadata iptc;
-#endif
-#ifdef HAVE_LCMS
-    GnomeCmdFileMetadata icc;
-#endif
-#ifdef HAVE_ID3
-    GnomeCmdFileMetadata id3;
-#endif
-#ifdef HAVE_GSF
-    GnomeCmdFileMetadata gsf;
-#endif
+    GnomeCmdFileMetadata *metadata;
 };
 
 struct _GnomeCmdFileClass
@@ -70,9 +49,9 @@ struct _GnomeCmdFileClass
     GnomeCmdFileInfoClass parent_class;
 };
 
-#include "gnome-cmd-dir.h"
 
-G_BEGIN_DECLS
+typedef struct _GnomeCmdDir         GnomeCmdDir;
+
 
 GtkType gnome_cmd_file_get_type (void);
 
@@ -99,8 +78,10 @@ gchar *gnome_cmd_file_get_quoted_name (GnomeCmdFile *file);
 gchar *gnome_cmd_file_get_path (GnomeCmdFile *finfo);
 gchar *gnome_cmd_file_get_real_path (GnomeCmdFile *finfo);
 gchar *gnome_cmd_file_get_quoted_real_path (GnomeCmdFile *finfo);
+gchar *gnome_cmd_file_get_dirname (GnomeCmdFile *finfo);
+gchar *gnome_cmd_file_get_unescaped_dirname (GnomeCmdFile *finfo);
 GnomeVFSURI *gnome_cmd_file_get_uri (GnomeCmdFile *finfo);
-gchar *gnome_cmd_file_get_uri_str (GnomeCmdFile *finfo);
+gchar *gnome_cmd_file_get_uri_str (GnomeCmdFile *finfo, GnomeVFSURIHideOptions hide_options=GNOME_VFS_URI_HIDE_NONE);
 
 const gchar *gnome_cmd_file_get_extension (GnomeCmdFile *finfo);
 const gchar *gnome_cmd_file_get_owner (GnomeCmdFile *finfo);
@@ -149,6 +130,4 @@ gboolean gnome_cmd_file_needs_update (GnomeCmdFile *finfo);
 void gnome_cmd_file_invalidate_tree_size (GnomeCmdFile *finfo);
 gboolean gnome_cmd_file_has_tree_size (GnomeCmdFile *finfo);
 
-G_END_DECLS
-
 #endif // __GNOME_CMD_FILE_H__
