@@ -14,11 +14,14 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
+#ifndef __GNOME_CMD_INCLUDES_H__
+#define __GNOME_CMD_INCLUDES_H__
 
 #include <libgcmd/libgcmd.h>
 
 typedef void *(*PthreadFunc)(void *);
 
+#endif // __GNOME_CMD_INCLUDES_H__
