@@ -56,9 +56,9 @@ typedef enum
 typedef struct
 {
     MenuType type;          // Type of item
-    const gchar *label;           // The text to use for this menu-item
-    const gchar *shortcut;        // The shortcut for this menu-item
-    const gchar *tooltip;         // The tooltip of this menu-item
+    const gchar *label;     // The text to use for this menu-item
+    const gchar *shortcut;  // The shortcut for this menu-item
+    const gchar *tooltip;   // The tooltip of this menu-item
     gpointer moreinfo;      // For an item, toggleitem, this is a pointer to the function to call when the item is activated.
     gpointer user_data;     // Data pointer to pass to callbacks
     GnomeUIPixmapType pixmap_type;    // Type of pixmap for the item
@@ -74,8 +74,7 @@ typedef struct
                                      * pointer to the filename string.
                                      */
 
-    GtkWidget *widget;        /* Filled in by gnome_app_create*, you can use this
-                               to tweak the widgets once they have been created */
+    GtkWidget *widget;      // Filled in by gnome_app_create*, you can use this to tweak the widgets once they have been created
 } MenuData;
 
 #define MENUTYPE_END { \
@@ -210,7 +209,6 @@ static GtkWidget *create_menu_item (GnomeCmdMainMenu *main_menu, GtkMenu *parent
             return NULL;
     }
 
-
     gtk_widget_show (item);
 
     if (spec->type == MENU_TYPE_ITEM)
@@ -229,20 +227,18 @@ static GtkWidget *create_menu_item (GnomeCmdMainMenu *main_menu, GtkMenu *parent
 
 static GtkWidget *create_menu (GnomeCmdMainMenu *main_menu, MenuData *spec, MenuData *childs)
 {
-    gint i=0;
-    GtkWidget *submenu, *menu_item;
+    GtkWidget *submenu = gtk_menu_new ();
+    GtkWidget *menu_item = create_menu_item (main_menu, NULL, spec);
 
-    submenu = gtk_menu_new ();
-    menu_item = create_menu_item (main_menu, NULL, spec);
     gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_item), submenu);
 
     gtk_widget_ref (menu_item);
     gtk_widget_show (menu_item);
 
-    while (childs[i].type != MENU_TYPE_END) {
+    for (gint i=0; childs[i].type != MENU_TYPE_END; ++i)
+    {
         GtkWidget *child = create_menu_item (main_menu, GTK_MENU (submenu), &childs[i]);
         gtk_menu_shell_append (GTK_MENU_SHELL (submenu), child);
-        i++;
     }
 
     return menu_item;
@@ -259,11 +255,11 @@ add_menu_item (GnomeCmdMainMenu *main_menu,
                GtkSignalFunc callback,
                gpointer user_data)
 {
+    g_return_val_if_fail (GTK_IS_MENU_SHELL (menu), NULL);
+
     GtkWidget *item, *label;
     GtkWidget *pixmap_widget = NULL;
 
-    g_return_val_if_fail (GTK_IS_MENU_SHELL (menu), NULL);
-
     item = gtk_image_menu_item_new ();
 
     if (tooltip)
@@ -387,12 +383,11 @@ static void update_view_menu (GnomeCmdMainMenu *main_menu)
     g_list_free (main_menu->priv->view_menuitems);
     main_menu->priv->view_menuitems = NULL;
 
-    item = add_menu_item (
-        main_menu,
-        GTK_MENU_SHELL (GTK_MENU_ITEM (main_menu->priv->view_menu)->submenu),
-        label, NULL,
-        pm, bm,
-        GTK_SIGNAL_FUNC (on_switch_orientation), main_menu);
+    item = add_menu_item (main_menu,
+                          GTK_MENU_SHELL (GTK_MENU_ITEM (main_menu->priv->view_menu)->submenu),
+                          label, NULL,
+                          pm, bm,
+                          GTK_SIGNAL_FUNC (on_switch_orientation), main_menu);
 
     g_free (label);
 
@@ -481,10 +476,17 @@ static void init (GnomeCmdMainMenu *main_menu)
             NULL
         },
         MENUTYPE_SEPARATOR,
+        {
+            MENU_TYPE_ITEM, _("Start _GNOME Commander as Root"), "", NULL,
+            (gpointer) command_root_mode, NULL,
+            GNOME_APP_PIXMAP_STOCK, GTK_STOCK_DIALOG_AUTHENTICATION,
+            NULL
+        },
+        MENUTYPE_SEPARATOR,
         {
             MENU_TYPE_ITEM, _("_Quit"), "Ctrl+Q", NULL,
             (gpointer) file_exit, NULL,
-            GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_QUIT,
+            GNOME_APP_PIXMAP_STOCK, GTK_STOCK_QUIT,
             NULL
         },
         MENUTYPE_END
@@ -543,25 +545,25 @@ static void init (GnomeCmdMainMenu *main_menu)
         {
             MENU_TYPE_ITEM, _("Cu_t"), "Ctrl+X", NULL,
             (gpointer) edit_cap_cut, NULL,
-            GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_CUT,
+            GNOME_APP_PIXMAP_STOCK, GTK_STOCK_CUT,
             NULL
         },
         {
             MENU_TYPE_ITEM, _("_Copy"), "Ctrl+C", NULL,
             (gpointer) edit_cap_copy, NULL,
-            GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_COPY,
+            GNOME_APP_PIXMAP_STOCK, GTK_STOCK_COPY,
             NULL
         },
         {
             MENU_TYPE_ITEM, _("_Paste"), "Ctrl+V", NULL,
             (gpointer) edit_cap_paste, NULL,
-            GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PASTE,
+            GNOME_APP_PIXMAP_STOCK, GTK_STOCK_PASTE,
             NULL
         },
         {
             MENU_TYPE_ITEM, _("_Delete"), "Delete", NULL,
             (gpointer) file_delete, NULL,
-            GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_TRASH,
+            GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_TRASH,
             NULL
         },
         MENUTYPE_SEPARATOR,
@@ -575,7 +577,7 @@ static void init (GnomeCmdMainMenu *main_menu)
         {
             MENU_TYPE_ITEM, _("_Search..."), "Alt+F7", NULL,
             (gpointer) edit_search, NULL,
-            GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SEARCH,
+            GNOME_APP_PIXMAP_STOCK, GTK_STOCK_FIND,
             NULL
         },
         {
@@ -598,19 +600,19 @@ static void init (GnomeCmdMainMenu *main_menu)
         {
             MENU_TYPE_ITEM, _("_Back"), "Alt+Left", NULL,
             (gpointer) view_back, NULL,
-            GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_BACK,
+            GNOME_APP_PIXMAP_STOCK, GTK_STOCK_GO_BACK,
             NULL
         },
         {
             MENU_TYPE_ITEM, _("_Forward"), "Alt+Right", NULL,
             (gpointer) view_forward, NULL,
-            GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_FORWARD,
+            GNOME_APP_PIXMAP_STOCK, GTK_STOCK_GO_FORWARD,
             NULL
         },
         {
             MENU_TYPE_ITEM, _("_Refresh"), "Ctrl+R", NULL,
             (gpointer) view_refresh, NULL,
-            GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_REFRESH,
+            GNOME_APP_PIXMAP_STOCK, GTK_STOCK_REFRESH,
             NULL
         },
         MENUTYPE_SEPARATOR,
@@ -699,8 +701,14 @@ static void init (GnomeCmdMainMenu *main_menu)
             GNOME_APP_PIXMAP_STOCK, GTK_STOCK_PREFERENCES,
             NULL
         },
-    {
-            MENU_TYPE_ITEM, _("Edit _MIME Types..."), "", NULL,
+        {
+            MENU_TYPE_ITEM, _("_Keyboard Shortcuts..."), "", NULL,
+            (gpointer) options_edit_shortcuts, NULL,
+            GNOME_APP_PIXMAP_STOCK, GTK_STOCK_ITALIC,
+            NULL
+        },
+        {
+            MENU_TYPE_ITEM, _("_MIME Types..."), "", NULL,
             (gpointer) options_edit_mime_types, NULL,
             GNOME_APP_PIXMAP_NONE, 0,
             NULL
@@ -736,7 +744,7 @@ static void init (GnomeCmdMainMenu *main_menu)
         {
             MENU_TYPE_ITEM, _("_Keyboard Shortcuts"), "", NULL,
             (gpointer) help_keyboard, NULL,
-            GNOME_APP_PIXMAP_NONE, 0,
+            GNOME_APP_PIXMAP_STOCK, GTK_STOCK_ITALIC,
             NULL
         },
         {
@@ -755,7 +763,7 @@ static void init (GnomeCmdMainMenu *main_menu)
         {
             MENU_TYPE_ITEM, _("_About"), "", NULL,
             (gpointer) help_about, NULL,
-            GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ABOUT,
+            GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_ABOUT,
             NULL
         },
         MENUTYPE_END
