@@ -123,8 +123,8 @@ static void gnome_cmd_main_win_real_switch_fs (GnomeCmdMainWin *mw, GnomeCmdFile
 
 gint gnome_cmd_key_snooper(GtkWidget *grab_widget, GdkEventKey *event, GnomeCmdMainWin *mw)
 {
-    g_return_val_if_fail(mw!=NULL, FALSE);
-    g_return_val_if_fail(mw->priv!=NULL,FALSE);
+    g_return_val_if_fail (mw!=NULL, FALSE);
+    g_return_val_if_fail (mw->priv!=NULL,FALSE);
 
     if (event->type!=GDK_KEY_PRESS)
         return FALSE;
@@ -144,13 +144,13 @@ gint gnome_cmd_key_snooper(GtkWidget *grab_widget, GdkEventKey *event, GnomeCmdM
     if (fs==NULL || fs->list==NULL)
         return FALSE;
 
-    if (!GTK_WIDGET_HAS_FOCUS(GTK_WIDGET(fs->list)))
+    if (!GTK_WIDGET_HAS_FOCUS (GTK_WIDGET (fs->list)))
         return FALSE;
 
-    if (gnome_cmd_file_list_quicksearch_shown(fs->list))
+    if (gnome_cmd_file_list_quicksearch_shown (fs->list))
         return FALSE;
 
-    gnome_cmd_file_list_show_quicksearch(fs->list, event->keyval);
+    gnome_cmd_file_list_show_quicksearch (fs->list, event->keyval);
 
     return TRUE;
 }
@@ -349,61 +349,61 @@ static GtkWidget *create_slide_popup ()
 
 static void on_help_clicked (GtkButton *button, GnomeCmdMainWin *mw)
 {
-    help_help (NULL, mw);
+    help_help (NULL);
 }
 
 
 static void on_rename_clicked (GtkButton *button, GnomeCmdMainWin *mw)
 {
-    file_rename (NULL, mw);
+    file_rename (NULL);
 }
 
 
 static void on_view_clicked (GtkButton *button, GnomeCmdMainWin *mw)
 {
-    file_view (NULL, mw);
+    file_view (NULL);
 }
 
 
 static void on_edit_clicked (GtkButton *button, GnomeCmdMainWin *mw)
 {
-    file_edit (NULL, mw);
+    file_edit (NULL);
 }
 
 
 static void on_copy_clicked (GtkButton *button, GnomeCmdMainWin *mw)
 {
-    file_copy (NULL, mw);
+    file_copy (NULL);
 }
 
 
 static void on_move_clicked (GtkButton *button, GnomeCmdMainWin *mw)
 {
-    file_move (NULL, mw);
+    file_move (NULL);
 }
 
 
 static void on_mkdir_clicked(GtkButton *button, GnomeCmdMainWin *mw)
 {
-    file_mkdir (NULL, mw);
+    file_mkdir (NULL);
 }
 
 
 static void on_delete_clicked (GtkButton *button, GnomeCmdMainWin *mw)
 {
-    file_delete (NULL, mw);
+    file_delete (NULL);
 }
 
 
 static void on_search_clicked (GtkButton *button, GnomeCmdMainWin *mw)
 {
-    edit_search (NULL, mw);
+    edit_search (NULL);
 }
 
 
 static void on_quit_clicked (GtkButton *button, GnomeCmdMainWin *mw)
 {
-    file_exit (NULL, mw);
+    file_exit (NULL);
 }
 
 
@@ -528,7 +528,7 @@ static void on_fs_list_resize_column (GtkCList *clist, gint column, gint width,
 
 static void on_size_allocate (GtkWidget *widget, GtkAllocation *allocation, gpointer user_data)
 {
-    switch(gnome_cmd_data_get_main_win_state())
+    switch (gnome_cmd_data_get_main_win_state())
     {
         case GDK_WINDOW_STATE_FULLSCREEN:
         case GDK_WINDOW_STATE_ICONIFIED:
@@ -761,7 +761,8 @@ static void init (GnomeCmdMainWin *mw)
     mw->priv->file_selector[LEFT] = NULL;
     mw->priv->file_selector[RIGHT] = NULL;
 
-    gnome_app_construct (GNOME_APP (main_win), "gnome-commander", _("GNOME Commander"));
+    gnome_app_construct (GNOME_APP (main_win), "gnome-commander", geteuid() ? _("GNOME Commander") :
+                                                                              _("GNOME Commander - ROOT PRIVILEGES"));
     gtk_object_set_data (GTK_OBJECT (main_win), "main_win", main_win);
     restore_size_and_pos (mw);
     gtk_window_set_policy (GTK_WINDOW (main_win), TRUE, TRUE, FALSE);
@@ -1019,11 +1020,6 @@ gboolean gnome_cmd_main_win_keypressed (GnomeCmdMainWin *mw, GdkEventKey *event)
                     clear_event_key (event);
                 }
                 return TRUE;
-
-            case GDK_Q:
-            case GDK_q:
-                gtk_widget_destroy (GTK_WIDGET (main_win));
-                return TRUE;
         }
     }
     else if (state_is_alt_shift (event->state))
