@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 #ifndef __GNOME_CMD_PREPARE_COPY_DIALOG_H__
 #define __GNOME_CMD_PREPARE_COPY_DIALOG_H__
@@ -22,8 +22,6 @@
 #include "gnome-cmd-file-list.h"
 #include "gnome-cmd-file-selector.h"
 
-void
-gnome_cmd_prepare_copy_dialog_show (GnomeCmdFileSelector *fs,
-                                    GnomeCmdFileSelector *to);
+void gnome_cmd_prepare_copy_dialog_show (GnomeCmdFileSelector *fs, GnomeCmdFileSelector *to);
 
-#endif //__GNOME_CMD_PREPARE_COPY_DIALOG_H__
+#endif // __GNOME_CMD_PREPARE_COPY_DIALOG_H__
