@@ -22,7 +22,7 @@
 #include "gnome-cmd-prepare-xfer-dialog.h"
 #include "gnome-cmd-dir.h"
 #include "gnome-cmd-xfer.h"
-#include "gnome-cmd-con.h"
+#include "gnome-cmd-con-list.h"
 #include "gnome-cmd-dir.h"
 #include "gnome-cmd-file.h"
 #include "gnome-cmd-file-selector.h"
@@ -35,28 +35,49 @@ using namespace std;
 static GnomeCmdDialogClass *parent_class = NULL;
 
 
+inline gboolean con_device_has_path (FileSelectorID fsID, GnomeCmdCon *&dev, const gchar *user_path)
+{
+    dev = gnome_cmd_file_selector_get_connection (gnome_cmd_main_win_get_fs (main_win, fsID));
+
+    return GNOME_CMD_IS_CON_DEVICE (dev) &&
+           g_str_has_prefix (user_path, gnome_cmd_con_device_get_mountp (GNOME_CMD_CON_DEVICE (dev)));
+}
+
+
 static void on_ok (GtkButton *button, GnomeCmdPrepareXferDialog *dialog)
 {
-    GnomeCmdDir *dest_dir;
-    gchar *dest_fn = NULL;
-    gchar *dest_path;
-
     GnomeCmdCon *con = gnome_cmd_dir_get_connection (dialog->default_dest_dir);
     gchar *user_path = g_strdup (gtk_entry_get_text (GTK_ENTRY (dialog->dest_dir_entry)));
+    gint user_path_len = strlen (user_path);
+
+    gchar *dest_path = user_path;
+    gchar *dest_fn = NULL;
+    GnomeCmdDir *dest_dir;
 
     // Make whatever the user entered into a valid path if possible
-    gint user_path_len = strlen (user_path);
+
     if (!user_path || user_path_len <= 0)
-    {
-        dest_path = user_path;
         goto bailout;
-    }
 
     if (user_path_len > 2 && user_path[user_path_len-1] == '/')
         user_path[user_path_len-1] = '\0';
 
     if (user_path[0] == '/')
-        dest_path = user_path;
+    {
+        if (gnome_cmd_file_is_local (GNOME_CMD_FILE (dialog->default_dest_dir)))   // hack to avoiding 'root' dir for mounted devices
+        {
+            GnomeCmdCon *dev;
+
+            // if LEFT or RIGHT device (connection) points to user_path than adjust user_path and set con to the found device
+            if (con_device_has_path (INACTIVE, dev, user_path) || con_device_has_path (ACTIVE, dev, user_path))
+            {
+                dest_path = g_strdup (user_path + strlen (gnome_cmd_con_device_get_mountp (GNOME_CMD_CON_DEVICE (dev))));
+                con = dev;
+            }
+            else    // otherwise connection not present in any pane, use home connection instead
+                con = get_home_con ();
+        }
+    }
     else
     {
         gchar *tmp = gnome_cmd_file_get_path (GNOME_CMD_FILE (gnome_cmd_file_selector_get_directory (dialog->src_fs)));
@@ -85,44 +106,89 @@ static void on_ok (GtkButton *button, GnomeCmdPrepareXferDialog *dialog)
             dest_fn = g_strdup (gnome_cmd_file_get_name (finfo));
         }
         else
-        if (res == GNOME_VFS_OK)
-        {
-            // There exists something else, asume that the user wants to overwrite it for now
-            gchar *tmp = g_path_get_dirname (dest_path);
-            dest_dir = gnome_cmd_dir_new (con, gnome_cmd_con_create_path (con, tmp));
-            g_free (tmp);
-            dest_fn = g_strdup (g_basename (dest_path));
-        }
-        else
-        {
-            // Nothing existed, check if the parent dir exists
-            gchar *parent_dir = g_path_get_dirname (dest_path);
-            res = gnome_cmd_con_get_path_target_type (con, parent_dir, &type);
-            if (res == GNOME_VFS_OK && type == GNOME_VFS_FILE_TYPE_DIRECTORY)
+            if (res == GNOME_VFS_OK)
             {
-                // yup, xfer to it
-                dest_dir = gnome_cmd_dir_new (con, gnome_cmd_con_create_path (con, parent_dir));
-                g_free (parent_dir);
+                // There exists something else, asume that the user wants to overwrite it for now
+                gchar *tmp = g_path_get_dirname (dest_path);
+                dest_dir = gnome_cmd_dir_new (con, gnome_cmd_con_create_path (con, tmp));
+                g_free (tmp);
                 dest_fn = g_strdup (g_basename (dest_path));
             }
-            else if (res == GNOME_VFS_OK)
+            else
             {
-                // the parent dir was a file, abort!
-                g_free (parent_dir);
+                // Nothing existed, check if the parent dir exists
+                gchar *parent_dir = g_path_get_dirname (dest_path);
+                res = gnome_cmd_con_get_path_target_type (con, parent_dir, &type);
+                if (res == GNOME_VFS_OK && type == GNOME_VFS_FILE_TYPE_DIRECTORY)
+                {
+                    // yup, xfer to it
+                    dest_dir = gnome_cmd_dir_new (con, gnome_cmd_con_create_path (con, parent_dir));
+                    g_free (parent_dir);
+                    dest_fn = g_strdup (g_basename (dest_path));
+                }
+                else
+                    if (res == GNOME_VFS_OK)
+                    {
+                        // the parent dir was a file, abort!
+                        g_free (parent_dir);
+                        goto bailout;
+                    }
+                    else
+                    {
+                        // Nothing exists, ask the user if a new directory might be suitable in the path that he specified
+                        gchar *msg = g_strdup_printf (_("The directory '%s' doesn't exist, do you want to create it?"),
+                                                      g_basename (parent_dir));
+                        gint choice = run_simple_dialog (GTK_WIDGET (dialog), TRUE, GTK_MESSAGE_QUESTION, msg, "",
+                                                         -1, _("No"), _("Yes"), NULL);
+                        g_free (msg);
+
+                        if (choice == 1)
+                        {
+                            GnomeVFSResult mkdir_result = gnome_cmd_con_mkdir (con, parent_dir);
+                            if (mkdir_result != GNOME_VFS_OK)
+                            {
+                                create_error_dialog (gnome_vfs_result_to_string (mkdir_result));
+                                goto bailout;
+                            }
+                        }
+                        else
+                            goto bailout;
+
+                        dest_dir = gnome_cmd_dir_new (con, gnome_cmd_con_create_path (con, parent_dir));
+                        g_free (parent_dir);
+                        dest_fn = g_strdup (g_basename (dest_path));
+                    }
+            }
+    }
+    else
+    {
+        if (res == GNOME_VFS_OK && type == GNOME_VFS_FILE_TYPE_DIRECTORY)
+        {
+            // There exists a directory, copy to it
+            dest_dir = gnome_cmd_dir_new (con, gnome_cmd_con_create_path (con, dest_path));
+        }
+        else
+            if (res == GNOME_VFS_OK)
+            {
+                // There exists something which is not a directory, abort!
                 goto bailout;
             }
             else
             {
                 // Nothing exists, ask the user if a new directory might be suitable in the path that he specified
                 gchar *msg = g_strdup_printf (_("The directory '%s' doesn't exist, do you want to create it?"),
-                                              g_basename (parent_dir));
-                gint choice = run_simple_dialog (GTK_WIDGET (dialog), TRUE, GTK_MESSAGE_QUESTION, msg, "",
-                                                 -1, _("No"), _("Yes"), NULL);
+                                              g_basename (dest_path));
+                GtkWidget *dialog = gtk_message_dialog_new (GTK_WINDOW (main_win),
+                                                            (GtkDialogFlags) 0,
+                                                            GTK_MESSAGE_QUESTION,
+                                                            GTK_BUTTONS_OK_CANCEL,
+                                                            msg);
+                gint choice = gtk_dialog_run (GTK_DIALOG (dialog));
                 g_free (msg);
 
-                if (choice == 1)
+                if (choice == GTK_RESPONSE_OK)
                 {
-                    GnomeVFSResult mkdir_result = gnome_cmd_con_mkdir (con, parent_dir);
+                    GnomeVFSResult mkdir_result = gnome_cmd_con_mkdir (con, dest_path);
                     if (mkdir_result != GNOME_VFS_OK)
                     {
                         create_error_dialog (gnome_vfs_result_to_string (mkdir_result));
@@ -132,51 +198,8 @@ static void on_ok (GtkButton *button, GnomeCmdPrepareXferDialog *dialog)
                 else
                     goto bailout;
 
-                dest_dir = gnome_cmd_dir_new (con, gnome_cmd_con_create_path (con, parent_dir));
-                g_free (parent_dir);
-                dest_fn = g_strdup (g_basename (dest_path));
+                dest_dir = gnome_cmd_dir_new (con, gnome_cmd_con_create_path (con, dest_path));
             }
-        }
-    }
-    else
-    {
-        if (res == GNOME_VFS_OK && type == GNOME_VFS_FILE_TYPE_DIRECTORY)
-        {
-            // There exists a directory, copy to it
-            dest_dir = gnome_cmd_dir_new (con, gnome_cmd_con_create_path (con, dest_path));
-        }
-        else if (res == GNOME_VFS_OK)
-        {
-            // There exists something which is not a directory, abort!
-            goto bailout;
-        }
-        else
-        {
-            // Nothing exists, ask the user if a new directory might be suitable in the path that he specified
-            gchar *msg = g_strdup_printf (_("The directory '%s' doesn't exist, do you want to create it?"),
-                                          g_basename (dest_path));
-            GtkWidget *dialog = gtk_message_dialog_new (GTK_WINDOW (main_win),
-                                                        (GtkDialogFlags) 0,
-                                                        GTK_MESSAGE_QUESTION,
-                                                        GTK_BUTTONS_OK_CANCEL,
-                                                        msg);
-            gint choice = gtk_dialog_run (GTK_DIALOG (dialog));
-            g_free (msg);
-
-            if (choice == GTK_RESPONSE_OK)
-            {
-                GnomeVFSResult mkdir_result = gnome_cmd_con_mkdir (con, dest_path);
-                if (mkdir_result != GNOME_VFS_OK)
-                {
-                    create_error_dialog (gnome_vfs_result_to_string (mkdir_result));
-                    goto bailout;
-                }
-            }
-            else
-                goto bailout;
-
-            dest_dir = gnome_cmd_dir_new (con, gnome_cmd_con_create_path (con, dest_path));
-        }
     }
 
     if (!GNOME_CMD_IS_DIR (dest_dir))
@@ -355,7 +378,7 @@ GtkWidget *gnome_cmd_prepare_xfer_dialog_new (GnomeCmdFileSelector *from, GnomeC
     {
         GnomeCmdFile *finfo = (GnomeCmdFile *) dialog->src_files->data;
 
-        gchar *t = gnome_cmd_file_get_path (GNOME_CMD_FILE (dialog->default_dest_dir));
+        gchar *t = gnome_cmd_file_get_real_path (GNOME_CMD_FILE (dialog->default_dest_dir));
         gchar *path = get_utf8 (t);
         gchar *fname = get_utf8 (finfo->info->name);
         g_free (t);
@@ -372,7 +395,7 @@ GtkWidget *gnome_cmd_prepare_xfer_dialog_new (GnomeCmdFileSelector *from, GnomeC
     }
     else
     {
-        gchar *t = gnome_cmd_file_get_path (GNOME_CMD_FILE (dialog->default_dest_dir));
+        gchar *t = gnome_cmd_file_get_real_path (GNOME_CMD_FILE (dialog->default_dest_dir));
         dest_str = get_utf8 (t);
         g_free (t);
     }
