@@ -22,8 +22,6 @@
 
 #include "gnome-cmd-main-win.h"
 
-G_BEGIN_DECLS
-
 typedef struct
 {
     gchar *name;        // plugin name
@@ -38,6 +36,4 @@ void python_plugin_manager_shutdown ();
 GList *gnome_cmd_python_plugin_get_list();
 gboolean gnome_cmd_python_plugin_execute(const PythonPluginData *plugin, GnomeCmdMainWin *mw);
 
-G_END_DECLS
-
 #endif // __GNOME_CMD_PYTHON_PLUGIN_H__
