@@ -20,11 +20,7 @@
 #define __GNOME_CMD_TYPES_H__
 
 typedef struct _GnomeCmdBookmarkGroup GnomeCmdBookmarkGroup;
-typedef gchar* GnomeCmdDateFormat;
-
-#include "gnome-cmd-con.h"
-
-G_BEGIN_DECLS
+typedef gchar *GnomeCmdDateFormat;
 
 typedef enum
 {
@@ -46,7 +42,7 @@ typedef enum
 typedef enum
 {
     GNOME_CMD_PERM_DISP_MODE_TEXT,
-    GNOME_CMD_PERM_DISP_MODE_NUMBER,
+    GNOME_CMD_PERM_DISP_MODE_NUMBER
 } GnomeCmdPermDispMode;
 
 
@@ -87,6 +83,9 @@ typedef struct
 } GnomeCmdColorTheme;
 
 
+typedef struct _GnomeCmdCon GnomeCmdCon;
+
+
 struct _GnomeCmdBookmarkGroup
 {
     GList *bookmarks;
@@ -95,12 +94,11 @@ struct _GnomeCmdBookmarkGroup
 };
 
 
-typedef struct {
+typedef struct
+{
     gchar *name;
     gchar *path;
     GnomeCmdBookmarkGroup *group;
 } GnomeCmdBookmark;
 
-G_END_DECLS
-
 #endif // __GNOME_CMD_TYPES_H__
