@@ -208,8 +208,7 @@ async_xfer_callback (GnomeVFSAsyncHandle *handle,
 }
 
 
-static gboolean
-update_xfer_gui_func (XferData *data)
+static gboolean update_xfer_gui_func (XferData *data)
 {
     if (data->win && data->win->cancel_pressed)
     {
@@ -441,7 +440,7 @@ gnome_cmd_xfer_uris_start (GList *src_uri_list,
                                                   xfer_callback,
                                                   data);
 
-    gtk_timeout_add (gnome_cmd_data_get_gui_update_rate (), (GtkFunction)update_xfer_gui_func, data);
+    g_timeout_add (gnome_cmd_data_get_gui_update_rate (), (GSourceFunc) update_xfer_gui_func, data);
 }
 
 
@@ -527,7 +526,7 @@ gnome_cmd_xfer_tmp_download_multiple (GList *src_uri_list,
                                    xfer_callback,
                                    data);
 
-    gtk_timeout_add (gnome_cmd_data_get_gui_update_rate (),
-                     (GtkFunction)update_xfer_gui_func,
-                     data);
+    g_timeout_add (gnome_cmd_data_get_gui_update_rate (),
+                   (GSourceFunc) update_xfer_gui_func,
+                   data);
 }
