@@ -22,9 +22,8 @@
 
 #include "gnome-cmd-file.h"
 
-G_BEGIN_DECLS
-
-typedef struct {
+typedef struct
+{
     GnomeVFSFileType type;
     gchar *ext;
     GdkColor *fg, *bg;
@@ -33,6 +32,4 @@ typedef struct {
 void     ls_colors_init (void);
 LsColor *ls_colors_get (GnomeCmdFile *finfo);
 
-G_END_DECLS
-
 #endif // __LS_COLORS_H__
