@@ -1,5 +1,5 @@
 /*
-    GNOME Commander - A GNOME based file manager 
+    GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
 
     This program is free software; you can redistribute it and/or modify
@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #ifndef __OWNER_H__
@@ -23,24 +23,21 @@
 #include <grp.h>
 #include <pwd.h>
 
-
 typedef struct
 {
-    gboolean zombie;  /* The gid of this group doesnt match any
-			 group in the system. */
+    gboolean zombie;    /* The gid of this group doesnt match any group in the system. */
     char *name;
     char *passwd;
     gid_t gid;
-    GList *members; /* stores the  members as char* strings */
+    GList *members;     /* stores the  members as char *strings */
 } group_t;
 
 
 typedef struct
 {
-    gboolean zombie;  /* The uid of this user doesnt match any
-			 user in the system. */
+    gboolean zombie;    /* The uid of this user doesnt match any user in the system. */
     char *name;
-    char *passwd;    
+    char *passwd;
     uid_t uid;
     gid_t gid;
     group_t *group;
@@ -64,5 +61,4 @@ const gchar *OWNER_get_name_by_gid (gid_t gid);
 uid_t OWNER_get_uid_by_name (const gchar *name);
 gid_t OWNER_get_gid_by_name (const gchar *name);
 
-
-#endif //__OWNER_H__
+#endif // __OWNER_H__
